aboutsummaryrefslogtreecommitdiff
path: root/engine/lib
diff options
context:
space:
mode:
authormarcus <marcus@36083f99-b078-4883-b0ff-0f9b5a30f544>2008-06-12 22:37:10 +0000
committermarcus <marcus@36083f99-b078-4883-b0ff-0f9b5a30f544>2008-06-12 22:37:10 +0000
commit5582e8070201138cc8ce76a3b900d3f1fbbc3337 (patch)
tree1555462cc44ecbc333b1f78eabd8e2851d201b0b /engine/lib
parentf93f66516b0ef1a2f36af5e5836772e0cce57468 (diff)
downloadelgg-5582e8070201138cc8ce76a3b900d3f1fbbc3337.tar.gz
elgg-5582e8070201138cc8ce76a3b900d3f1fbbc3337.tar.bz2
- Moved statistics to their own component views. Yay.
Marcus Povey git-svn-id: https://code.elgg.org/elgg/trunk@906 36083f99-b078-4883-b0ff-0f9b5a30f544
Diffstat (limited to 'engine/lib')
-rw-r--r--engine/lib/admin.php2
-rw-r--r--engine/lib/statistics.php78
2 files changed, 46 insertions, 34 deletions
diff --git a/engine/lib/admin.php b/engine/lib/admin.php
index f1e088eca..3c34b51c1 100644
--- a/engine/lib/admin.php
+++ b/engine/lib/admin.php
@@ -39,8 +39,6 @@
*/
function admin_init()
{
- global $CONFIG;
-
// Add plugin main menu option (last)
extend_elgg_admin_page('admin/main_opt/statistics', 'admin/main');
extend_elgg_admin_page('admin/main_opt/site', 'admin/main');
diff --git a/engine/lib/statistics.php b/engine/lib/statistics.php
index f5bf23250..844cbfa01 100644
--- a/engine/lib/statistics.php
+++ b/engine/lib/statistics.php
@@ -2,7 +2,8 @@
/**
* Elgg statistics library.
* This file contains a number of functions for obtaining statistics about the running system.
* These statistics are mainly used by the administration pages.
*
* @package Elgg
* @subpackage Core
@@ -50,40 +51,53 @@
return $entity_stats;
}
- /**
- * Return the number of users registered in the system.
- *
- * @return int
- */
- function get_number_users()
- {
- global $CONFIG;
+ /**
+ * Return the number of users registered in the system.
+ *
+ * @return int
+ */
+ function get_number_users()
+ {
+ global $CONFIG;
- $result = get_data_row("SELECT count(*) as count from {$CONFIG->dbprefix}entities where type='user'");
+ $result = get_data_row("SELECT count(*) as count from {$CONFIG->dbprefix}entities where type='user'");
- if ($result)
- return $result->count;
+ if ($result)
+ return $result->count;
- return false;
- }
+ return false;
+ }
+
+ /**
+ * Report how many users are currently online
+ *
+ * @return int
+ */
+ function get_number_online()
+ {
+ // TODO: get logged in users somehow
+ }
- /**
- * Report how many users are currently online
- *
- * @return int
- */
- function get_number_online()
- {
- // TODO: get logged in users somehow
- }
+ /**
+ * Return a list of how many users are currently online.
+ *
+ * @param int $limit Number of users to return
+ */
+ function get_online_users($limit = 10)
+ {
+ // TODO: Writeme
+ }
- /**
- * Return a list of how many users are currently online.
- *
- * @param int $limit Number of users to return
- */
- function get_online_users($limit = 10)
- {
- // TODO: Writeme
- }
+ /**
+ * Initialise the statistics admin page.
+ */
+ function statistics_init()
+ {
+ extend_elgg_admin_page('admin/statistics_opt/basic', 'admin/statistics');
+ extend_elgg_admin_page('admin/statistics_opt/numentities', 'admin/statistics');
+ extend_elgg_admin_page('admin/statistics_opt/online', 'admin/statistics');
+ }
+
+ /// Register init function
+ register_elgg_event_handler('init','system','statistics_init');
?>
@@ -2,7 +2,8 @@
* Elgg statistics library.
* This file contains a number of functions for obtaining statistics about the running system.
- * These statistics are mainly used by the administration pages.
+ * These statistics are mainly used by the administration pages, and is also where the basic views for statistics
+ * are added.
*
* @package Elgg